## $Id: pages.py 14974 2018-03-20 18:57:43Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from zope.component import getUtility
from zope.catalog.interfaces import ICatalog
from waeup.kofa.browser.pages import (
    SessionConfigurationAddFormPage, SessionConfigurationManageFormPage,
    LoginPage, CertificatePage, CertificateManageFormPage)
from waeup.kofa.university.interfaces import ICertificate
from waeup.kofa.interfaces import IUniversity
from waeup.uniben.interfaces import (
    ICustomSessionConfiguration, ICustomSessionConfigurationAdd)


class ShowDuplicatePayments(grok.View):
    """List (in plain text format) payment ids which have been
    imported several times for different students.
    """

    grok.context(IUniversity)
    grok.name('replicated_payments')
    grok.require('waeup.managePortal')

    def search_replicated_payments(self):
        cat = getUtility(ICatalog, name='payments_catalog')
        all = list(cat.searchResults(p_id=(None, None)))
        output = ''
        hitlist = []
        for item in all:
            if not getattr(item,'student', None) or item.p_id in hitlist:
                continue
            replicates = cat.searchResults(p_id=(item.p_id, item.p_id))
            if len(replicates) > 1:
                hitlist.append(item.p_id)
                replicates_line = ''
                for p in replicates:
                    student = getattr(p,'student', None)
                    if student is not None:
                        replicates_line += '%s (%s),%s,' % (
                            student.student_id,
                            student.matric_number,
                            student.email)
                output += "%s,%s\n" % (item.p_id, replicates_line)
        return output

    def render(self):
        return self.search_replicated_payments()


class CustomSessionConfigurationAddFormPage(SessionConfigurationAddFormPage):
    """Add a session configuration object to configuration container.
    """
    form_fields = grok.AutoFields(ICustomSessionConfigurationAdd)

class CustomSessionConfigurationManageFormPage(SessionConfigurationManageFormPage):
    """Manage session configuration object.
    """
    form_fields = grok.AutoFields(ICustomSessionConfiguration)

class CustomLoginPage(LoginPage):

    def _comment(self, student):
        return None

class CustomCertificatePage(CertificatePage):
    """Index page for certificates.
    """
    form_fields = grok.AutoFields(ICertificate).omit(
        'ratio',
        'custom_textline_1', 'custom_textline_2',
        'custom_float_2')

class CustomCertificateManageFormPage(CertificateManageFormPage):
    """Manage the properties of a `Certificate` instance.
    """
    form_fields = grok.AutoFields(ICertificate).omit(
        'ratio',
        'custom_textline_1', 'custom_textline_2',
        'custom_float_2', 'code')
